package com.qmth.cqb.base.service;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

import com.qmth.cqb.base.dao.QuesTypeRepo;
import com.qmth.cqb.base.model.QuesType;
import com.qmth.cqb.utils.modal.NormalResponse;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;

/**
 * Created by songyue on 16/12/28.
 */
@Service
public class QuesTypeService {
	
	@Autowired
	QuesTypeRepo quesTypeRepo;
	
    @Autowired
    MongoTemplate mongoTemplate;
    
    /**
     * 查询所题型
     * @param searchCondition
     * @param curPage
     * @param pageSize
     * @return
     */
    public PagingAndSortingResponse<QuesType> findAll(QuesType searchCondition, int curPage, int pageSize){
        Page<QuesType> quesTypeList = quesTypeRepo.findAll(Example.of(searchCondition),new PageRequest(curPage-1,pageSize));
        return new PagingAndSortingResponse<QuesType>(quesTypeList.getNumber(),quesTypeList.getSize(),
        		quesTypeList.getTotalPages(),quesTypeList.getTotalElements(),quesTypeList.getContent());
    }

    
    /**
     * 保存题型
     * @param quesType
     * @return
     */
    public QuesType saveQuesType(QuesType quesType){
    	QuesType tempPaper = quesTypeRepo.save(quesType);
    	return tempPaper;
//        if(tempPaper != null){
//            return new NormalResponse(HttpStatus.OK.toString(),"success");
//        }else{
//            return new NormalResponse(HttpStatus.INTERNAL_SERVER_ERROR.toString(),"保存失败");
//        }
    }
    
    /**
     * 删除题型
     * @param quesTypeId
     * @return
     */
    public NormalResponse deleteQuesType(String quesTypeId){
    	quesTypeRepo.delete(quesTypeId);
        return new NormalResponse(HttpStatus.OK.toString(),"success");
    }
    
    /**
     * 根据课程名称查找题型
     * @param typeId
     * @return
     */
    public QuesType findByName(String typeName){
        return quesTypeRepo.findByTypeName(typeName);
    }

}
