package com.qmth.cqb.base.web;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.google.gson.Gson;
import com.qmth.cqb.base.dao.CourseRepo;
import com.qmth.cqb.base.model.Course;
import com.qmth.cqb.base.model.Role;
import com.qmth.cqb.base.service.CourseService;
import com.qmth.cqb.utils.modal.NormalResponse;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;

/**
 * Created by songyue on 16/12/26.
 */

@RestController
@RequestMapping("${api_cqb}/")
public class CourseController {
    @Autowired
    Gson gson;
    
    @Autowired
    CourseRepo courseRepo;

    @Autowired
    CourseService courseService;


    /**
     * 获取全部课程
     * @return
     */
    @GetMapping(value = "/course/all/{curPage}/{paseSize}")
    public PagingAndSortingResponse<Course> getAllCourse(@ModelAttribute Course searchCondition, @PathVariable int curPage, @PathVariable int pageSize){
        //return courseService.findAll(searchCondition,new PageRequest(curPage - 1,pageSize));
        Page<Course> courseList = courseRepo.findAll(Example.of(searchCondition),new PageRequest(curPage-1,pageSize));
        return new PagingAndSortingResponse<Course>(courseList.getNumber(),courseList.getSize(),
        		courseList.getTotalPages(),courseList.getTotalElements(),courseList.getContent());
    }

    /**
     * 更新课程
     * @param user
     * @return
     */
    @PutMapping(value = "/course")
    public NormalResponse updateCourse(@ModelAttribute Course course){
    	return courseService.saveCourse(course);
    }

    /**
     * 新增课程
     * @param course
     * @return
     */
    @PostMapping(value = "/course")
    public NormalResponse addCourse(@ModelAttribute Course course){
    	return courseService.saveCourse(course);
    }

    /**
     * 删除课程
     * @param 课程ID coruse_id
     * @return
     */
    @DeleteMapping(value = "/course/{coruse_id}")
    public NormalResponse removeCourse(@PathVariable String coruse_id){
    	return courseService.deleteCourse(coruse_id);
    }
    
    /**
     * 根据课程名称或者课程编号获取课程信息
     * @param courseName
     * @return
     */
    @GetMapping(value = "/course/{keyword}")
    public List<Course> getCourseByKeyword(@PathVariable String keyword){
        return courseService.findCoursesByKeyword(keyword);
    }

}
