package com.qmth.cqb.base.web;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.google.gson.Gson;
import com.qmth.cqb.base.dao.QuesTypeRepo;
import com.qmth.cqb.base.model.QuesType;
import com.qmth.cqb.base.service.QuesTypeService;
import com.qmth.cqb.utils.modal.NormalResponse;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;

/**
 * Created by songyue on 16/12/26.
 */
@RestController
@RequestMapping("${api_cqb}/")
public class QuesTypeController {
	
    @Autowired
    QuesTypeRepo quesTypeRepo;

    @Autowired
    Gson gson;
    

    @Autowired
    QuesTypeService quesTypeService;


    /**
     * 获取全部题型
     * @return
     */
    @GetMapping(value = "/quesType/all/{curPage}/{paseSize}")
    public PagingAndSortingResponse<QuesType> getAllQuesType(@ModelAttribute QuesType searchCondition, @PathVariable int curPage, @PathVariable int pageSize){
    	 return quesTypeService.findAll(searchCondition,curPage, pageSize);
    }

    /**
     * 更新题型
     * @param user
     * @return
     */
    @PutMapping(value = "/quesType")
    public NormalResponse updateQuesType(@ModelAttribute QuesType quesType){
    	quesTypeService.saveQuesType(quesType);
        return new NormalResponse(HttpStatus.OK.toString(),"success");
    }

    /**
     * 新增题型
     * @param quesType
     * @return
     */
    @PostMapping(value = "/quesType")
    public NormalResponse addQuesType(@ModelAttribute QuesType quesType){
	    quesTypeService.saveQuesType(quesType);
	    return new NormalResponse(HttpStatus.OK.toString(),"success");
    }

    /**
     * 删除题型
     * @param 题型ID quesType_id
     * @return
     */
    @DeleteMapping(value = "/quesType/{quesType_id}")
    //ResponseEntity
    public NormalResponse removeQuesType(@PathVariable String quesType_id){
    	return quesTypeService.deleteQuesType(quesType_id);
    }
    
    /**
     * 根据题型名称获取题型信息
     * @param quesTypeName
     * @return
     */
    @GetMapping(value = "/quesType/{quesType_name}")
    public QuesType getQuesTypeByName(@PathVariable String quesType_name){
        return quesTypeService.findByName(quesType_name);
    }
}
