package com.qmth.cqb.paper.service;

import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import com.qmth.cqb.utils.CommonUtils;
import org.apache.commons.collections4.IteratorUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.stereotype.Service;

import com.qmth.cqb.paper.dao.ExamPaperRepo;
import com.qmth.cqb.paper.dao.PaperRepo;
import com.qmth.cqb.paper.model.ExamPaper;
import com.qmth.cqb.paper.model.Paper;
import com.qmth.cqb.paper.model.PaperDetail;

/**
 * Created by songyue on 16/12/28.
 */
@Service
public class PaperService {
	
	@Autowired
	PaperRepo paperRepo;
	
	@Autowired
	PaperDetailService paperDetailService;
	
	@Autowired
	ExamPaperRepo examPaperRepo; 
	
	
	
	/**
	 * 查询考试试卷
	 * @param id
	 * @param courseCode
	 * @param groupCode
	 * @return
	 */
    public List<Paper> listExamPapers(long id,String courseCode,String groupCode){
    	List<Paper> papers = new ArrayList<Paper>();
     	ExamPaper examPaper = new ExamPaper();
    	examPaper.setExamId(id);
    	examPaper.setCourseCode(courseCode);
    	examPaper.setGroupCode(groupCode);
    	Example<ExamPaper> example = Example.of(examPaper); 
    	List<ExamPaper> examPapers = examPaperRepo.findAll(example);
    	for(ExamPaper ePaper:examPapers){
    		Paper paper = paperRepo.findOne(ePaper.getPaperId());
    		papers.add(paper);
    	}
		return papers;
    }
    
    
    /**
     * 设置考试试卷
     * @param examId
     * @param courseCode
     * @param groupCode
     * @param paperId
     * @return
     */
    public void joinToExamPaper(long examId,
								String courseCode,
								String groupCode,
								String paperId){
		ExamPaper examPaper = new ExamPaper();
		examPaper.setExamId(examId);
		examPaper.setGroupCode(groupCode);
		examPaper.setCourseCode(courseCode);
		examPaper.setPaperId(paperId);
		examPaperRepo.save(examPaper);
    }
    
    public void releaseExamPaper(long examId,
									String courseCode,
									String groupCode,
									String paperId){
		ExamPaper examPaper = new ExamPaper();
		examPaper.setExamId(examId);
		examPaper.setGroupCode(groupCode);
		examPaper.setCourseCode(courseCode);
		examPaper.setPaperId(paperId);
		examPaperRepo.delete(examPaper);
    }
    
    
    public Set<String> listGroupCodes(long examId,String courseCode){
    	Set<String> groupSet = new HashSet<String>();
    	ExamPaper examPaper = new ExamPaper();
    	examPaper.setExamId(examId);
		examPaper.setCourseCode(courseCode);
		List<ExamPaper> examPapers = examPaperRepo.findAll(Example.of(examPaper));
		for(ExamPaper expaper:examPapers){
			groupSet.add(expaper.getGroupCode());
		}
		return groupSet;
    }
    
    
    public void deletGroupCode(long examId,String courseCode,String groupCode){
    	ExamPaper examPaper = new ExamPaper();
    	examPaper.setExamId(examId);
		examPaper.setCourseCode(courseCode);
		examPaper.setCourseCode(courseCode);
		examPaperRepo.delete(examPaper);
    }
    
    
    /**
     * 根据试卷ID获取试卷下面的大题
     * @param id
     * @return
     */
    public List<PaperDetail> findPaperDetailsById(String id){
        return paperDetailService.getPaperDetailsByPaper(paperRepo.findOne(id));
    }

    /**
     * 按ID查询试卷
     * @param id
     * @return
     */
    public Paper findById(String id){
        return paperRepo.findOne(id);
    }

    /**
     * 保存试卷
     * @param pd
     * @return
     */
    public Paper savePaper(Paper pd){
        return paperRepo.save(pd);
    }

	/**
	 * 删除试卷
	 * @param paper
     */
    public void deletePaper(Paper paper){
    	paperDetailService.deletePaperDetailsByPaper(paper);
		paperRepo.delete(paper);
	}

	/**
	 * 批量删除试卷
	 * @param paperId
     */
	public void deletePapers(String [] paperId){
		List<Paper> papers = CommonUtils.toList(paperRepo.findAll(Arrays.asList(paperId)));
		paperDetailService.deletePaperDetailsByPapers(papers);
		paperRepo.delete(papers);
	}

}
