package com.qmth.cqb.paper.web;

import com.qmth.cqb.paper.dao.PaperRepo;
import com.qmth.cqb.paper.model.ImportPaperSearchCondition;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.qmth.cqb.paper.model.Paper;
import com.qmth.cqb.paper.service.ImportPaperService;
import com.qmth.cqb.utils.modal.PagingAndSortingResponse;

/**
 * Created by songyue on 16/12/28.
 */
@RestController
@RequestMapping("${api_cqb}/")
public class ImportPaperController {
	
	@Autowired
	ImportPaperService importPaperService;

    @Autowired
    PaperRepo paperRepo;

    /**
     * 获取导入试卷
     * @param id
     * @return
     */
    @GetMapping(value = "/importPaper/{id}")
    public ResponseEntity getPaperById(@PathVariable String id){
        return new ResponseEntity(paperRepo.findOne(id),HttpStatus.OK);
    }

    /**
     * 获取全部导入试卷
     * @return
     */
    @GetMapping(value = "/importPaper/{curPage}/{paseSize}")
    public ResponseEntity getAllPaper(@ModelAttribute ImportPaperSearchCondition searchCondition,                                            @PathVariable int curPage,
                                      @PathVariable int pageSize){

      return new ResponseEntity(importPaperService.findAll(searchCondition,
              curPage,pageSize), HttpStatus.OK);
    }

    /**
     * 获取全部导入试卷
     * @return
     */
    @GetMapping(value = "/importPaper/{courseId}/{curPage}/{pageSize}")
    public ResponseEntity getImportPapersByCourseId(
    		                              @PathVariable String courseId,
    		                              @PathVariable int curPage,
    		                              @PathVariable int pageSize
    		                              ){
      return new ResponseEntity(importPaperService.getImportPapersByCourseId(courseId,
              curPage, pageSize),HttpStatus.OK);
    }


    /**
     * 更新导入试卷信息
     * @param 
     * @return
     */
    @PutMapping(value = "/importPaper")
    public ResponseEntity updatePaper(@ModelAttribute Paper paper){
    	return new ResponseEntity(paperRepo.save(paper),HttpStatus.OK);
    }

    /**
     * 新增导入试卷
     * @param paper
     * @return
     */
    @PostMapping(value = "/importPaper")
    public ResponseEntity addPaper(@ModelAttribute Paper paper){
    	return new ResponseEntity(paperRepo.save(paper),HttpStatus.OK);
    }

    /**
     * 删除导入试卷
     * @param id
     * @return
     */
    @DeleteMapping(value = "/importPaper/{id}")
    public ResponseEntity removePaper(@PathVariable String id){
    	paperRepo.delete(id);
		return new ResponseEntity(HttpStatus.OK);
    }
}
